#contentview-preview .icon-preview:before{content:"\e833"}.pat-sortable>:hover{cursor:move}.pat-sortable{display:block;position:relative}.pat-sortable .sortable-section{border:1px solid #dee2e6!important;margin-bottom:1rem;margin-top:1rem;padding:.5rem}.hidden-section-title{opacity:.3}.section-title{vertical-align:middle}.content-section h2,.section-title,.show-hide-banner{display:inline-block}.show-hide-banner{background:#fff;border:1px solid #e6e6e6;padding:15px}.header-section{background:#f2f2f2;line-height:1.9;margin-bottom:1rem!important;margin-top:1rem!important;padding:0 1rem}table.table_schedule{cursor:default}ul.plonetoolbar-authentic-sources-menu,ul.plonetoolbar-smartweb-help-menu{padding-inline-start:0;width:100%}a.manage[class*=contenttype-imio-smartweb-]:before{display:none}a.manage[class*=contenttype-imio-smartweb-] svg{margin-right:5px}