#contentview-preview .icon-preview:before {
  content: '\e833';
}

.pat-sortable> :hover {
  cursor: move;
}

.pat-sortable {
  position: relative;
  display: block;

  .sortable-section {
    padding: 0.5rem;
    margin-top: 1rem;
    margin-bottom: 1rem;
    border: 1px solid #dee2e6 !important;
  }
}

.hidden-section-title {
  opacity: 0.3;
}

.section-title {
  display: inline-block;
  vertical-align: middle;
}

.content-section {
  h2 {
    display: inline-block;
  }
}

.show-hide-banner {
  display: inline-block;
  padding: 15px;
  background: #fff;
  border: solid 1px #e6e6e6;
}

.header-section {
  background: #f2f2f2;
  padding: 0 1rem;
  line-height: 1.9;
  margin-top: 1rem !important;
  margin-bottom: 1rem !important;
}

table.table_schedule {
  cursor: default;
}

ul.plonetoolbar-authentic-sources-menu {
  padding-inline-start: 0;
  width: 100%;
}

ul.plonetoolbar-smartweb-help-menu {
  padding-inline-start: 0;
  width: 100%;
}

a.manage[class*="contenttype-imio-smartweb-"] {
    &:before {
        display: none;
    }
    svg {
      margin-right: 5px;
    }
}